Struct pcaparse::cap::CapReader

source ·
pub struct CapReader<R> { /* private fields */ }
Reads a cap from a reader.

Example

use std::fs::File;

use pcaparse::cap::CapReader;

let file_in = File::open("test.cap").expect("Error opening file");
let mut cap_reader = CapReader::new(file_in).unwrap();

// Read test.cap
while let Some(pkt) = cap_reader.next_packet() {
    //Check if there is no error
    let pkt = pkt.unwrap();

    //Do something
}

Implementations

source

impl<R> CapReader<R>

source

pub fn header(&self) -> CapHeader

Returns the global header of the cap.

source

impl<R: Read> CapReader<R>

source

pub fn new(reader: R) -> Result<CapReader<R>, PcapError>

Creates a new CapReader from an existing reader.

This function reads the global cap header of the file to verify its integrity.

The underlying reader must point to a valid cap file/stream.

Errors

The data stream is not in a valid cap file format.

The underlying data are not readable.

source

pub fn into_reader(self) -> R

Consumes Self, returning the wrapped reader.

source

pub fn next_packet(&mut self) -> Option<Result<CapPacket<'_>, PcapError>>

Returns the next CapPacket.

source

pub fn next_raw_packet(&mut self) -> Option<Result<RawCapPacket<'_>, PcapError>>

Returns the next RawCapPacket.