Struct pcaparse::pcap::PcapReader
source · pub struct PcapReader<R> { /* private fields */ }Expand description
Reads a pcap from a reader.
Example
use std::fs::File;
use pcaparse::pcap::PcapReader;
let file_in = File::open("test.pcap").expect("Error opening file");
let mut pcap_reader = PcapReader::new(file_in).unwrap();
// Read test.pcap
while let Some(pkt) = pcap_reader.next_packet() {
//Check if there is no error
let pkt = pkt.unwrap();
//Do something
}Implementations
sourceimpl<R> PcapReader<R>
impl<R> PcapReader<R>
sourcepub fn header(&self) -> PcapHeader
pub fn header(&self) -> PcapHeader
Returns the global header of the pcap.
sourceimpl<R: Read> PcapReader<R>
impl<R: Read> PcapReader<R>
sourcepub fn new(reader: R) -> Result<PcapReader<R>, PcapError>
pub fn new(reader: R) -> Result<PcapReader<R>, PcapError>
Creates a new PcapReader from an existing reader.
This function reads the global pcap header of the file to verify its integrity.
The underlying reader must point to a valid pcap file/stream.
Errors
The data stream is not in a valid pcap file format.
The underlying data are not readable.
sourcepub fn into_reader(self) -> R
pub fn into_reader(self) -> R
Consumes Self, returning the wrapped reader.
sourcepub fn next_packet(&mut self) -> Option<Result<PcapPacket<'_>, PcapError>>
pub fn next_packet(&mut self) -> Option<Result<PcapPacket<'_>, PcapError>>
Returns the next PcapPacket.
sourcepub fn next_raw_packet(
&mut self
) -> Option<Result<RawPcapPacket<'_>, PcapError>>
pub fn next_raw_packet( &mut self ) -> Option<Result<RawPcapPacket<'_>, PcapError>>
Returns the next RawPcapPacket.